@@ -1,7 +1,7 @@
 package App::ProgUtils;
 
-our $DATE = '2014-11-28'; # DATE
-our $VERSION = '0.14'; # VERSION
+our $DATE = '2015-03-21'; # DATE
+our $VERSION = '0.15'; # VERSION
 
 use 5.010001;
 use strict;
@@ -58,21 +58,52 @@ App::ProgUtils - Command line to manipulate programs in PATH
 
 =head1 VERSION
 
-This document describes version 0.14 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2014-11-28.
+This document describes version 0.15 of App::ProgUtils (from Perl distribution App-ProgUtils), released on 2015-03-21.
 
 =head1 SYNOPSIS
 
-This distribution provides the following command-line utilities:
+This distribution provides the following command-line utilities related to
+programs found in PATH.
 
- progcat
- progedit
- progless
- progman
- progpath
+The main feature of these utilities is tab completion.
+
+=head1 FAQ
+
+=head2 What is the purpose of this distribution? Haven't other similar utilities existed?
+
+For example, L<mpath> from L<Module::Path> distribution is similar to L<pmpath>
+in L<App::PMUtils>, and L<mversion> from L<Module::Version> distribution is
+similar to L<pmversion> from L<App::PMUtils> distribution, and so on.
+
+True. The main point of these utilities is shell tab completion, to save
+typing.
 
 =head1 SEE ALSO
 
-L<App::PMUtils>, a similarly spirited distribution.
+Below is the list of distributions that provide CLI utilities for various
+purposes, with the focus on providing shell tab completion feature.
+
+L<App::DistUtils>, utilities related to Perl distributions.
+
+L<App::DzilUtils>, utilities related to L<Dist::Zilla>.
+
+L<App::GitUtils>, utilities related to git.
+
+L<App::IODUtils>, utilities related to L<IOD> configuration files.
+
+L<App::LedgerUtils>, utilities related to Ledger CLI files.
+
+L<App::OrgUtils>, utilities related to Org files.
+
+L<App::PlUtils>, utilities related to Perl scripts.
+
+L<App::PMUtils>, utilities related to Perl modules.
+
+L<App::ProgUtils>, utilities related to programs.
+
+L<App::UpfUtils>, utilities related to Unix password/shadow files.
+
+L<App::WeaverUtils>, utilities related to L<Pod::Weaver>.
 
 =head1 HOMEPAGE
 
@@ -80,7 +111,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-ProgUt
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-ProgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-ProgUtils>.
 
 =head1 BUGS
 
@@ -96,7 +127,7 @@ perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2014 by perlancar@cpan.org.
+This software is copyright (c) 2015 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
